@@ -15,67 +15,99 @@
 # limitations under the License.
 #
 
+from warnings import warn
 from pyspark import keyword_only
-
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgoBase import H2OTreeBasedSupervisedAlgoBase
-from ai.h2o.sparkling.ml.params import H2OGBMParams
+from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgorithm import H2OTreeBasedSupervisedAlgorithm
+from ai.h2o.sparkling.ml.models.H2OGBMMOJOModel import H2OGBMMOJOModel
+from ai.h2o.sparkling.ml.params.H2OGBMParams import H2OGBMParams
+from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
+from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
-class H2OGBM(H2OGBMParams, H2OTreeBasedSupervisedAlgoBase):
+
+class H2OGBM(H2OGBMParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
+                 monotoneConstraints={},
+                 calibrationDataFrame=None,
+                 ignoredCols=None,
+                 columnsToCategorical=[],
+                 withContributions=False,
+                 withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
+                 convertInvalidNumbersToNa=False,
+                 detailedPredictionCol="detailed_prediction",
+                 validationDataFrame=None,
+                 featuresCols=[],
+                 predictionCol="prediction",
+                 convertUnknownCategoricalLevelsToNa=False,
+                 splitRatio=1.0,
+                 withStageResults=False,
+                 withDetailedPredictionCol=True,
                  learnRate=0.1,
                  learnRateAnnealing=1.0,
+                 sampleRate=1.0,
                  colSampleRate=1.0,
-                 maxAbsLeafnodePred=Utils.javaDoubleMaxValue,
+                 maxAbsLeafnodePred=1.7976931348623157E308,
                  predNoiseBandwidth=0.0,
-                 quantileAlpha=0.5,
+                 balanceClasses=False,
+                 classSamplingFactors=None,
+                 maxAfterBalanceSize=5.0,
+                 maxConfusionMatrixSize=20,
                  ntrees=50,
                  maxDepth=5,
                  minRows=10.0,
                  nbins=20,
+                 nbinsTopLevel=1024,
                  nbinsCats=1024,
-                 minSplitImprovement=1e-5,
-                 histogramType="AUTO",
-                 nbinsTopLevel=1 << 10,
+                 seed=-1,
                  buildTreeOneNode=False,
-                 scoreTreeInterval=0,
-                 sampleRate=1.0,
                  sampleRatePerClass=None,
-                 colSampleRateChangePerLevel=1.0,
                  colSampleRatePerTree=1.0,
+                 colSampleRateChangePerLevel=1.0,
+                 scoreTreeInterval=0,
+                 minSplitImprovement=1.0E-5,
+                 histogramType="AUTO",
+                 calibrateModel=False,
+                 checkConstantResponse=True,
                  modelId=None,
+                 nfolds=0,
+                 keepCrossValidationModels=True,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationFoldAssignment=False,
-                 parallelizeCrossValidation=True,
                  distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
                  labelCol="label",
-                 foldCol=None,
                  weightCol=None,
                  offsetCol=None,
-                 splitRatio=1.0,
-                 seed=-1,
-                 nfolds=0,
-                 allStringColumnsToCategorical=True,
-                 columnsToCategorical=[],
-                 predictionCol="prediction",
-                 detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=False,
-                 featuresCols=[],
-                 convertUnknownCategoricalLevelsToNa=False,
-                 convertInvalidNumbersToNa=False,
-                 namedMojoOutputColumns=True,
-                 monotoneConstraints={},
+                 foldCol=None,
+                 foldAssignment="AUTO",
+                 categoricalEncoding="AUTO",
+                 ignoreConstCols=True,
+                 scoreEachIteration=False,
                  stoppingRounds=0,
+                 maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
-                 withContributions=False):
+                 customMetricFunc=None,
+                 customDistributionFunc=None,
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGBM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGBM", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+
+        if 'interactionPairs' in kwargs:
+            warn("Interaction pairs are not supported!")
         self._set(**kwargs)
+        self._transfer_params_to_java()
+
+    def _create_model(self, javaModel):
+        return H2OGBMMOJOModel(javaModel)
